@@ -212,38 +212,20 @@ drawCell(ModeInfo * mi, int col, int row, unsigned char state)
 		int orient = ((row & 1) * 2 + col) % 4;
 		int offsetX = 0, offsetY = 0;
 		switch (orient) {
-#if 0
 		case 0: /* up */
 			offsetX = dp->xs;
 			break;
 		case 1: /* down */
-			offsetY = 4 * dp->ys / 3;
+			offsetY = 3 * dp->ys / 2 - 1;
 			break;
 		case 2: /* left */
-			offsetX = -dp->xs / 3;
-			offsetY = 2 * dp->ys / 3;
+			offsetX = -dp->xs / 2;
+			offsetY = 3 * dp->ys / 4;
 			break;
 		case 3: /* right */
-			offsetX = 4 * dp->xs / 3;
-			offsetY = 2 * dp->ys / 3;
+			offsetX = 3 * dp->xs / 2 - 1;
+			offsetY = 3 * dp->ys / 4;
 			break;
-#else
-		case 0: /* up */
-			offsetX = dp->xs;
-			offsetY = -1;
-			break;
-		case 1: /* down */
-			offsetY = dp->ys;
-			break;
-		case 2: /* left */
-			offsetX = -2;
-			offsetY = dp->ys / 2;
-			break;
-		case 3: /* right */
-			offsetX = dp->xs;
-			offsetY = dp->ys / 2;
-			break;
-#endif
 		default:
 			(void) printf("wrong orient %d\n", orient);
 		}
@@ -484,38 +466,20 @@ draw_state(ModeInfo * mi, int state)
 			int offsetX = 0, offsetY = 0;
 
 			switch (orient) {
-#if 0
 			case 0: /* up */
 				offsetX = dp->xs;
 				break;
 			case 1: /* down */
-				offsetY = 4 * dp->ys / 3;
+				offsetY = 3 * dp->ys / 2 - 1;
 				break;
 			case 2: /* left */
-				offsetX = -dp->xs / 3;
-				offsetY = 2 * dp->ys / 3;
+				offsetX = -dp->xs / 2;
+				offsetY = 3 * dp->ys / 4;
 				break;
 			case 3: /* right */
-				offsetX = 4 * dp->xs / 3;
-				offsetY = 2 * dp->ys / 3;
+				offsetX = 3 * dp->xs / 2 - 1;
+				offsetY = 3 * dp->ys / 4;
 				break;
-#else
-			case 0: /* up */
-				offsetX = dp->xs;
-				offsetY = -1;
-				break;
-			case 1: /* down */
-				offsetY = dp->ys;
-				break;
-			case 2: /* left */
-				offsetX = -2;
-				offsetY = dp->ys / 2;
-				break;
-			case 3: /* right */
-				offsetX = dp->xs;
-				offsetY = dp->ys / 2;
-				break;
-#endif
 			default:
 				(void) printf("wrong orient %d\n", orient);
 			}
@@ -1125,23 +1089,16 @@ init_demon(ModeInfo * mi)
 			dp->xs = MIN(size, MAX(MINSIZE, MIN(dp->width, dp->height) /
 				MINGRIDSIZE));
 		dp->ys = dp->xs * 2;
-		dp->ncols = (MAX(dp->width / dp->xs, 8) / 4) * 4;
-		dp->nrows = (MAX(dp->height / dp->ys, 8)) / 2 * 2;
+		dp->ncols = (MAX((dp->width - 4) / dp->xs, 8) / 4) * 4;
+		dp->nrows = (MAX((dp->height - dp->ys / 2) / dp->ys, 8)) / 2 * 2;
 		dp->xb = (dp->width - dp->xs * dp->ncols) / 2;
-		dp->yb = (dp->height - dp->ys * dp->nrows) / 2;
+		dp->yb = (dp->height - dp->ys * dp->nrows) / 2 - 2;
 		for (orient = 0; orient < 4; orient++) {
 			for (sides = 0; sides < 5; sides++) {
-#if 0
 				dp->shape.pentagon[orient][sides].x =
-					2 * dp->xs * pentagonUnit[orient][sides].x / 3;
+					2 * (dp->xs - 1) * pentagonUnit[orient][sides].x / 4;
 				dp->shape.pentagon[orient][sides].y =
-					dp->ys * pentagonUnit[orient][sides].y / 3;
-#else
-				dp->shape.pentagon[orient][sides].x =
-					dp->xs * pentagonUnit[orient][sides].x / 2;
-				dp->shape.pentagon[orient][sides].y =
-					dp->ys * pentagonUnit[orient][sides].y / 4;
-#endif
+					(dp->ys - 1) * pentagonUnit[orient][sides].y / 4;
 			}
 		}
 	} else {		/* TRI */
