@@ -955,6 +955,20 @@ ClearMem(life3dstruct * lp)
 		}
 }
 
+/* Checks to make sure there is a cell there */
+static Bool cellCheck(int neighbors, int x, int y, int z)
+{
+	return (neighbors != 12 || ((x + y + z) & 1) == 0);
+}
+
+/* Checks to make sure it wraps well */
+static Bool boundsCheck12(int neighbors, int x, int y, int z) {
+	return (neighbors != 12 || ((x + y + z) & 1) == 0);
+}
+
+static Bool boundsCheck14(int polyhedron, int z) {
+	return (neighbors != 14 || (z & 1) == 0);
+}
 
 /*-
  * This routine increments the values stored in the 27 cells centered on
@@ -970,7 +984,7 @@ IncrementNbrs3D(life3dstruct * lp, CellList * cell)
 		x = xc = cell->x;
 		y = yc = cell->y;
 		z = zc = cell->z;
-		if (lp->neighbors == 12 && ((x + y + z) & 1) == 0)
+		if (!cellCheck(lp->neighbors, x, y, z))
 			continue;
 	/*if (patternsearch &&
 		(x == MAXCOLUMNS / 2 - 1 || y == MAXROWS / 2 - 1 || z == MAXSTACKS / 2 - 1))
@@ -1032,7 +1046,7 @@ RunLife3D(life3dstruct * lp)
 			x = xc = ptr->x;
 			y = yc = ptr->y;
 			z = zc = ptr->z;
-			if (lp->neighbors == 12 && ((x + y + z) & 1) == 0)
+			if (!cellCheck(lp->neighbors, x, y, z))
 				continue;
 			positionOfNeighbor(lp, i, &x, &y, &z);
 			if (x != xc || y != yc || z != zc) {
@@ -1504,6 +1518,12 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 				patptr = &patterns_14S34B46[pat][0];
 #ifdef LIFE_NAMES
 				patstrg = &patterns_14S34B46[2 * pattern][0];
+#endif
+				break;
+			case LIFE_14S56B45:
+				patptr = &patterns_14S56B45[pat][0];
+#ifdef LIFE_NAMES
+				patstrg = &patterns_14S56B45[2 * pattern][0];
 #endif
 				break;
 			}
@@ -1606,6 +1626,12 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 				patptr = &patterns_26S57B6[pat][0];
 #ifdef LIFE_NAMES
 				patstrg = &patterns_26S57B6[2 * pattern][0];
+#endif
+				break;
+			case LIFE_26S57B67:
+				patptr = &patterns_26S57B67[pat][0];
+#ifdef LIFE_NAMES
+				patstrg = &patterns_26S57B67[2 * pattern][0];
 #endif
 				break;
 			case LIFE_26S58B5:
@@ -2092,37 +2118,37 @@ DrawRhombicDodecahedron(ModeInfo * mi, CellList * cell)
 	*/
 	if (lp->wireframe) {
 		if (dx <= LEN) {
-		drawQuad(mi, (int) (GREEN & mask), pts, 2, 5, 0, 3);
-		drawQuad(mi, (int) (GREEN & mask), pts, 13, 4, 0, 6);
-		drawQuad(mi, (int) (RED & mask), pts, 3, 0, 4, 1);
-		drawQuad(mi, (int) (RED & mask), pts, 5, 12, 6, 0);
+		drawQuad(mi, (int) (GREEN & mask), pts, 0, 3, 2, 5);
+		drawQuad(mi, (int) (GREEN & mask), pts, 0, 6, 13, 4);
+		drawQuad(mi, (int) (RED & mask), pts, 0, 4, 1, 3);
+		drawQuad(mi, (int) (RED & mask), pts, 0, 5, 12, 6);
 		} else if (dx >= -LEN) {
-		drawQuad(mi, (int) (GREEN & mask), pts, 2, 9, 12, 5);
+		drawQuad(mi, (int) (GREEN & mask), pts, 2, 7, 11, 9);
 		drawQuad(mi, (int) (GREEN & mask), pts, 1, 8, 11, 7);
-		drawQuad(mi, (int) (RED & mask), pts, 7, 1, 8, 11);
+		drawQuad(mi, (int) (RED & mask), pts, 8, 13, 10, 11);
 		drawQuad(mi, (int) (RED & mask), pts, 9, 11, 10, 12);
 		}
 		if (dy <= LEN) {
-		drawQuad(mi, (int) (RED & mask), pts, 3, 0, 4, 1);
-		drawQuad(mi, (int) (RED & mask), pts, 7, 1, 8, 11);
-		drawQuad(mi, (int) (BLUE & mask), pts, 2, 3, 1, 7);
-		drawQuad(mi, (int) (BLUE & mask), pts, 13, 8, 1, 4);
+		drawQuad(mi, (int) (RED & mask), pts, 0, 4, 1, 3);
+		drawQuad(mi, (int) (RED & mask), pts, 1, 8, 11, 7);
+		drawQuad(mi, (int) (BLUE & mask), pts, 1, 7, 2, 3);
+		drawQuad(mi, (int) (BLUE & mask), pts, 1, 4, 13, 8);
 		} else if (dy >= -LEN) {
-		drawQuad(mi, (int) (RED & mask), pts, 5, 12, 6, 0);
+		drawQuad(mi, (int) (RED & mask), pts, 0, 5, 12, 6);
 		drawQuad(mi, (int) (RED & mask), pts, 9, 11, 10, 12);
 		drawQuad(mi, (int) (BLUE & mask), pts, 2, 9, 12, 5);
-		drawQuad(mi, (int) (BLUE & mask), pts, 13, 6, 12, 10);
+		drawQuad(mi, (int) (BLUE & mask), pts, 6, 12, 10, 13);
 		}
 		if (dz <= LEN) {
-		drawQuad(mi, (int) (BLUE & mask), pts, 2, 3, 1, 7);
+		drawQuad(mi, (int) (BLUE & mask), pts, 1, 7, 2, 3);
 		drawQuad(mi, (int) (BLUE & mask), pts, 2, 9, 12, 5);
 		drawQuad(mi, (int) (GREEN & mask), pts, 2, 7, 11, 9);
-		drawQuad(mi, (int) (GREEN & mask), pts, 2, 5, 0, 3);
+		drawQuad(mi, (int) (GREEN & mask), pts, 0, 3, 2, 5);
 		} else if (dz >= -LEN) {
-		drawQuad(mi, (int) (BLUE & mask), pts, 13, 8, 1, 4);
-		drawQuad(mi, (int) (BLUE & mask), pts, 13, 6, 12, 10);
-		drawQuad(mi, (int) (GREEN & mask), pts, 13, 4, 0, 6);
-		drawQuad(mi, (int) (GREEN & mask), pts, 13, 10, 11, 8);
+		drawQuad(mi, (int) (BLUE & mask), pts, 1, 4, 13, 8);
+		drawQuad(mi, (int) (BLUE & mask), pts, 6, 12, 10, 13);
+		drawQuad(mi, (int) (GREEN & mask), pts, 0, 6, 13, 4);
+		drawQuad(mi, (int) (GREEN & mask), pts, 8, 13, 10, 11);
 		}
 	}
 	sortx = sorty = sortz = 0;
@@ -2143,50 +2169,50 @@ DrawRhombicDodecahedron(ModeInfo * mi, CellList * cell)
 	    if (dx > LEN) {
 	      if (sortz > sorty) {
 		if (dz < 0)
-		  drawQuad(mi, (int) (GREEN & mask), pts, 2, 5, 0, 3);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 0, 3, 2, 5);
 		else
-		  drawQuad(mi, (int) (GREEN & mask), pts, 13, 4, 0, 6);
-		drawQuad(mi, (int) (RED & mask), pts, 3, 0, 4, 1);
-		drawQuad(mi, (int) (RED & mask), pts, 5, 12, 6, 0);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 0, 6, 13, 4);
+		drawQuad(mi, (int) (RED & mask), pts, 0, 5, 12, 6);
+		drawQuad(mi, (int) (RED & mask), pts, 0, 4, 1, 3);
 		if (dz < 0)
-		  drawQuad(mi, (int) (GREEN & mask), pts, 13, 4, 0, 6);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 0, 6, 13, 4);
 		else
-		  drawQuad(mi, (int) (GREEN & mask), pts, 2, 5, 0, 3);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 0, 3, 2, 5);
 	      } else {
 		if (dy < 0)
-		  drawQuad(mi, (int) (RED & mask), pts, 3, 0, 4, 1);
+		  drawQuad(mi, (int) (RED & mask), pts, 0, 4, 1, 3);
 		else
-		  drawQuad(mi, (int) (RED & mask), pts, 5, 12, 6, 0);
-		drawQuad(mi, (int) (GREEN & mask), pts, 2, 5, 0, 3);
-		drawQuad(mi, (int) (GREEN & mask), pts, 13, 4, 0, 6);
+		  drawQuad(mi, (int) (RED & mask), pts, 0, 5, 12, 6);
+		drawQuad(mi, (int) (GREEN & mask), pts, 0, 6, 13, 4);
+		drawQuad(mi, (int) (GREEN & mask), pts, 0, 3, 2, 5);
 		if (dy < 0)
-		  drawQuad(mi, (int) (RED & mask), pts, 5, 12, 6, 0);
+		  drawQuad(mi, (int) (RED & mask), pts, 0, 5, 12, 6);
 		else
-		  drawQuad(mi, (int) (RED & mask), pts, 3, 0, 4, 1);
+		  drawQuad(mi, (int) (RED & mask), pts, 0, 4, 1, 3);
 	      }
 	    } else if (dx < -LEN) {
 	      if (sortz > sorty) {
 		if (dz < 0)
 		  drawQuad(mi, (int) (GREEN & mask), pts, 2, 7, 11, 9);
 		else
-		  drawQuad(mi, (int) (GREEN & mask), pts, 13, 10, 11, 8);
-		drawQuad(mi, (int) (RED & mask), pts, 7, 1, 8, 11);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 8, 13, 10, 11);
 		drawQuad(mi, (int) (RED & mask), pts, 9, 11, 10, 12);
+		drawQuad(mi, (int) (RED & mask), pts, 1, 8, 11, 7);
 		if (dz < 0)
-		  drawQuad(mi, (int) (GREEN & mask), pts, 13, 10, 11, 8);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 8, 13, 10, 11);
 		else
 		  drawQuad(mi, (int) (GREEN & mask), pts, 2, 7, 11, 9);
 	      } else {
 		if (dy < 0)
-		  drawQuad(mi, (int) (RED & mask), pts, 7, 1, 8, 11);
+		  drawQuad(mi, (int) (RED & mask), pts, 1, 8, 11, 7);
 		else
 	  	  drawQuad(mi, (int) (RED & mask), pts, 9, 11, 10, 12);
+		drawQuad(mi, (int) (GREEN & mask), pts, 8, 13, 10, 11);
 		drawQuad(mi, (int) (GREEN & mask), pts, 2, 7, 11, 9);
-		drawQuad(mi, (int) (GREEN & mask), pts, 13, 10, 11, 8);
 		if (dy < 0)
 	  	  drawQuad(mi, (int) (RED & mask), pts, 9, 11, 10, 12);
 		else
-		  drawQuad(mi, (int) (RED & mask), pts, 7, 1, 8, 11);
+		  drawQuad(mi, (int) (RED & mask), pts, 1, 8, 11, 7);
 	      }
 	    }
 	  }
@@ -2194,48 +2220,48 @@ DrawRhombicDodecahedron(ModeInfo * mi, CellList * cell)
 	    if (dy > LEN) {
 	      if (sortx > sortz) {
 		if (dx < 0)
-		  drawQuad(mi, (int) (RED & mask), pts, 3, 0, 4, 1);
+		  drawQuad(mi, (int) (RED & mask), pts, 0, 4, 1, 3);
 		else
-		  drawQuad(mi, (int) (RED & mask), pts, 7, 1, 8, 11);
-		drawQuad(mi, (int) (BLUE & mask), pts, 2, 3, 1, 7);
-		drawQuad(mi, (int) (BLUE & mask), pts, 13, 8, 1, 4);
+		  drawQuad(mi, (int) (RED & mask), pts, 1, 8, 11, 7);
+		drawQuad(mi, (int) (BLUE & mask), pts, 1, 4, 13, 8);
+		drawQuad(mi, (int) (BLUE & mask), pts, 1, 7, 2, 3);
 		if (dx < 0)
-		  drawQuad(mi, (int) (RED & mask), pts, 7, 1, 8, 11);
+		  drawQuad(mi, (int) (RED & mask), pts, 1, 8, 11, 7);
 		else
-		  drawQuad(mi, (int) (RED & mask), pts, 3, 0, 4, 1);
+		  drawQuad(mi, (int) (RED & mask), pts, 0, 4, 1, 3);
 	      } else {
 		if (dz < 0)
-		  drawQuad(mi, (int) (BLUE & mask), pts, 2, 3, 1, 7);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 1, 7, 2, 3);
 		else
-		  drawQuad(mi, (int) (BLUE & mask), pts, 13, 8, 1, 4);
-		drawQuad(mi, (int) (RED & mask), pts, 3, 0, 4, 1);
-		drawQuad(mi, (int) (RED & mask), pts, 7, 1, 8, 11);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 1, 4, 13, 8);
+		drawQuad(mi, (int) (RED & mask), pts, 1, 8, 11, 7);
+		drawQuad(mi, (int) (RED & mask), pts, 0, 4, 1, 3);
 		if (dz < 0)
-		  drawQuad(mi, (int) (BLUE & mask), pts, 13, 8, 1, 4);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 1, 4, 13, 8);
 		else
-		  drawQuad(mi, (int) (BLUE & mask), pts, 2, 3, 1, 7);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 1, 7, 2, 3);
 	      }
 	    } else if (dy < -LEN) {
 	      if (sortx > sortz) {
 		if (dx < 0)
-		  drawQuad(mi, (int) (RED & mask), pts, 5, 12, 6, 0);
+		  drawQuad(mi, (int) (RED & mask), pts, 0, 5, 12, 6);
 		else
 		  drawQuad(mi, (int) (RED & mask), pts, 9, 11, 10, 12);
+		drawQuad(mi, (int) (BLUE & mask), pts, 6, 12, 10, 13);
 		drawQuad(mi, (int) (BLUE & mask), pts, 2, 9, 12, 5);
-		drawQuad(mi, (int) (BLUE & mask), pts, 13, 6, 12, 10);
 		if (dx < 0)
 		  drawQuad(mi, (int) (RED & mask), pts, 9, 11, 10, 12);
 		else
-		  drawQuad(mi, (int) (RED & mask), pts, 5, 12, 6, 0);
+		  drawQuad(mi, (int) (RED & mask), pts, 0, 5, 12, 6);
 	      } else {
 		if (dz < 0)
 		  drawQuad(mi, (int) (BLUE & mask), pts, 2, 9, 12, 5);
 		else
-		  drawQuad(mi, (int) (BLUE & mask), pts, 13, 6, 12, 10);
-		drawQuad(mi, (int) (RED & mask), pts, 5, 12, 6, 0);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 6, 12, 10, 13);
 		drawQuad(mi, (int) (RED & mask), pts, 9, 11, 10, 12);
+		drawQuad(mi, (int) (RED & mask), pts, 0, 5, 12, 6);
 		if (dz < 0)
-		  drawQuad(mi, (int) (BLUE & mask), pts, 13, 6, 12, 10);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 6, 12, 10, 13);
 		else
 		  drawQuad(mi, (int) (BLUE & mask), pts, 2, 9, 12, 5);
 	      }
@@ -2245,50 +2271,50 @@ DrawRhombicDodecahedron(ModeInfo * mi, CellList * cell)
 	    if (dz > LEN) {
 	      if (sorty > sortx) {
 		if (dy < 0)
-		  drawQuad(mi, (int) (BLUE & mask), pts, 2, 3, 1, 7);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 1, 7, 2, 3);
 		else
 		  drawQuad(mi, (int) (BLUE & mask), pts, 2, 9, 12, 5);
-		drawQuad(mi, (int) (GREEN & mask), pts, 2, 5, 0, 3);
+		drawQuad(mi, (int) (GREEN & mask), pts, 0, 3, 2, 5);
 		drawQuad(mi, (int) (GREEN & mask), pts, 2, 7, 11, 9);
 		if (dy < 0)
 		  drawQuad(mi, (int) (BLUE & mask), pts, 2, 9, 12, 5);
 		else
-		  drawQuad(mi, (int) (BLUE & mask), pts, 2, 3, 1, 7);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 1, 7, 2, 3);
 	      } else {
 		if (dx < 0)
-		  drawQuad(mi, (int) (GREEN & mask), pts, 2, 5, 0, 3);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 0, 3, 2, 5);
 		else
 		  drawQuad(mi, (int) (GREEN & mask), pts, 2, 7, 11, 9);
-		drawQuad(mi, (int) (BLUE & mask), pts, 2, 3, 1, 7);
 		drawQuad(mi, (int) (BLUE & mask), pts, 2, 9, 12, 5);
+		drawQuad(mi, (int) (BLUE & mask), pts, 1, 7, 2, 3);
 		if (dx < 0)
 		  drawQuad(mi, (int) (GREEN & mask), pts, 2, 7, 11, 9);
 		else
-		  drawQuad(mi, (int) (GREEN & mask), pts, 2, 5, 0, 3);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 0, 3, 2, 5);
 	      }
 	    } else if (dz < -LEN) {
 	      if (sorty > sortx) {
 		if (dy < 0)
-		  drawQuad(mi, (int) (BLUE & mask), pts, 13, 8, 1, 4);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 1, 4, 13, 8);
 		else
-		  drawQuad(mi, (int) (BLUE & mask), pts, 13, 6, 12, 10);
-		drawQuad(mi, (int) (GREEN & mask), pts, 13, 4, 0, 6);
-		drawQuad(mi, (int) (GREEN & mask), pts, 13, 10, 1, 8);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 6, 12, 10, 13);
+		drawQuad(mi, (int) (GREEN & mask), pts, 1, 8, 13, 10);
+		drawQuad(mi, (int) (GREEN & mask), pts, 0, 6, 13, 4);
 		if (dy < 0)
-		  drawQuad(mi, (int) (BLUE & mask), pts, 13, 6, 12, 10);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 6, 12, 10, 13);
 		else
-		  drawQuad(mi, (int) (BLUE & mask), pts, 13, 8, 1, 4);
+		  drawQuad(mi, (int) (BLUE & mask), pts, 1, 4, 13, 8);
 	      } else {
 		if (dx < 0)
-		  drawQuad(mi, (int) (GREEN & mask), pts, 13, 4, 0, 6);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 0, 6, 13, 4);
 		else
-		  drawQuad(mi, (int) (GREEN & mask), pts, 13, 10, 1, 8);
-		drawQuad(mi, (int) (BLUE & mask), pts, 13, 8, 1, 4);
-		drawQuad(mi, (int) (BLUE & mask), pts, 13, 6, 12, 10);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 1, 8, 13, 10);
+		drawQuad(mi, (int) (BLUE & mask), pts, 6, 12, 10, 13);
+		drawQuad(mi, (int) (BLUE & mask), pts, 1, 4, 13, 8);
 		if (dx < 0)
-		  drawQuad(mi, (int) (GREEN & mask), pts, 13, 10, 1, 8);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 1, 8, 13, 10);
 		else
-		  drawQuad(mi, (int) (GREEN & mask), pts, 13, 4, 0, 6);
+		  drawQuad(mi, (int) (GREEN & mask), pts, 0, 6, 13, 4);
 	      }
 	    }
 	  }
@@ -2539,7 +2565,8 @@ orthogonal(life3dstruct * lp) /* or full diagonal */
 	if (lp->neighbors == 12)
 		return (lp->patterned_rule == LIFE_12S456B3);
 	else if (lp->neighbors == 18)
-		return (lp->patterned_rule == LIFE_18S45B4);
+		return ((lp->patterned_rule == LIFE_18S45B4) &&
+			(LRAND() & 1));
 	else if (lp->neighbors == 20)
 		return (lp->patterned_rule == LIFE_20S45B4);
 	else if (lp->neighbors == 26)
@@ -2551,13 +2578,21 @@ orthogonal(life3dstruct * lp) /* or full diagonal */
 			(lp->patterned_rule == LIFE_26S37B5) ||
 			(lp->patterned_rule == LIFE_26S4B5) ||
 			(lp->patterned_rule == LIFE_26S47B5) ||
-			(lp->patterned_rule == LIFE_26S58B5));
+			((lp->patterned_rule == LIFE_26S56B5) &&
+			(LRAND() & 1)) ||
+			((lp->patterned_rule == LIFE_26S57B6) &&
+			(NRAND(4) == 0)) ||
+			((lp->patterned_rule == LIFE_26S58B5) &&
+			(NRAND(4) == 0)) ||
+			((lp->patterned_rule == LIFE_26S678B5) &&
+			(LRAND() & 1)));
 	return False;
 }
 
 static Bool
 populateGlider(life3dstruct * lp, char *glider, int offsetSwitch,
-		int hsp, int vsp, int asp, int hoff, int voff, int aoff) {
+		int hsp, int vsp, int asp, int hoff, int voff, int aoff)
+{
 	int x, y, z, temp;
 
 	while ((x = *glider++) != 127) {
@@ -2598,10 +2633,154 @@ populateGlider(life3dstruct * lp, char *glider, int offsetSwitch,
 	return True;
 }
 
+/* My rule of thumb is if there is an 18 cell (or less) glider add it here */
+static void
+populateGliders(life3dstruct * lp, int dim, int orth,
+		int hsp, int vsp, int asp, int hoff, int voff, int aoff)
+{
+	if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12S3B3) {
+		if (NRAND(3)) {
+			(void) populateGlider(lp, glider_12S3B3[0], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		} else if (NRAND(3)) {
+			(void) populateGlider(lp, glider_12S3B3[1], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		} else { /* lower probability of big glider */
+			(void) populateGlider(lp, glider_12S3B3[2], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		}
+	} else if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12S456B3) {
+		(void) populateGlider(lp, glider_12S456B3[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 14 && lp->patterned_rule == LIFE_14S34B4) {
+		(void) populateGlider(lp, glider_14S34B4[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 14 && lp->patterned_rule == LIFE_14S34B46) {
+		(void) populateGlider(lp, glider_14S34B46[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 18 && lp->patterned_rule == LIFE_18S45B4) {
+		if (orth) {
+			if (LRAND() & 1) {
+				(void) populateGlider(lp, glider_18S45B4[0], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+			} else {
+				(void) populateGlider(lp, glider_18S45B4[1], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+			}
+		} else {
+			(void) populateGlider(lp, glider_18S45B4[2], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		}
+	} else if (lp->neighbors == 20 && lp->patterned_rule == LIFE_20S45B4) {
+		if (LRAND() & 1) {
+			(void) populateGlider(lp, glider_20S45B4[0], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		} else {
+			(void) populateGlider(lp, glider_20S45B4[1], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		}
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S23B5) {
+		(void) populateGlider(lp, glider_26S23B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S25B5) {
+		(void) populateGlider(lp, glider_26S25B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S27B5) {
+		(void) populateGlider(lp, glider_26S27B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S35B5) {
+		(void) populateGlider(lp, glider_26S35B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S36B5) {
+		(void) populateGlider(lp, glider_26S36B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S37B5) {
+		(void) populateGlider(lp, glider_26S37B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S38B5) {
+		if (LRAND() & 1) {
+			(void) populateGlider(lp, glider_26S38B5[0], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		} else {
+			(void) populateGlider(lp, glider_26S38B5[1], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		}
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S4B5) {
+		(void) populateGlider(lp, glider_26S4B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S45B5) {
+		(void) populateGlider(lp, glider_26S45B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S47B5) {
+		(void) populateGlider(lp, glider_26S47B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S56B5) {
+		if (orth) {
+			if (LRAND() & 1) {
+				(void) populateGlider(lp, glider_26S56B5[0], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+			} else {
+				(void) populateGlider(lp, glider_26S56B5[1], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+			}
+		} else {
+			(void) populateGlider(lp, glider_26S56B5[2], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		}
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S567B6) {
+		(void) populateGlider(lp, glider_26S567B6[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S57B6) {
+		if (orth) {
+			if (LRAND() & 1) {
+				(void) populateGlider(lp, glider_26S57B6[1], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+			} else {
+				(void) populateGlider(lp, glider_26S57B6[2], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+			}
+		} else {
+			(void) populateGlider(lp, glider_26S57B6[0], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		}
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S57B67) {
+		(void) populateGlider(lp, glider_26S57B67[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S58B5) {
+		if (orth)
+			(void) populateGlider(lp, glider_26S58B5[4], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		else if (NRAND(3)) {
+			if (LRAND() & 1)
+				(void) populateGlider(lp, glider_26S58B5[0], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+			else if (LRAND() & 1)
+				(void) populateGlider(lp, glider_26S58B5[1], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+			else
+				(void) populateGlider(lp, glider_26S58B5[2], dim,
+					hsp, vsp, asp, hoff, voff, aoff);
+		} else
+			(void) populateGlider(lp, glider_26S58B5[3], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S678B5) {
+		if (orth) {
+			(void) populateGlider(lp, glider_26S678B5[1], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		} else {
+			(void) populateGlider(lp, glider_26S678B5[0], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
+		}
+	} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S8B5) {
+		(void) populateGlider(lp, glider_26S8B5[0], dim,
+			hsp, vsp, asp, hoff, voff, aoff);
+	}
+}
+
 static Bool
 shooter(life3dstruct * lp)
 {
-	int hsp, vsp, asp, hoff = 1, voff = 1, aoff = 1, r, c2, r2, s2;
+	int hsp, vsp, asp, hoff = 1, voff = 1, aoff = 1, dim, c2, r2, s2, orth;
 
 	/* Generate the glider at the edge of the screen */
 #define V 10
@@ -2609,9 +2788,10 @@ shooter(life3dstruct * lp)
 	c2 = lp->ncols / 2;
 	r2 = lp->nrows / 2;
 	s2 = lp->nstacks / 2;
-	r = NRAND(3);
-	if (!r) {
-		if (orthogonal(lp)) {
+	dim = NRAND(3);
+	orth = orthogonal(lp);
+	if (!dim) {
+		if (orth) {
 			hsp = (LRAND() & 1) ? c2 - V : c2 + V;
 			vsp = NRAND(V2) + r2 - V2 / 2;
 			asp = NRAND(V2) + s2 - V2 / 2;
@@ -2626,106 +2806,26 @@ shooter(life3dstruct * lp)
 			voff = -1;
 		if (hsp > c2)
 			hoff = -1;
-		if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12S3B3) {
+		if (lp->neighbors == 12) {
 			/* Must ensure we have only odd cells (x+y+z=odd)
 			   for glider, so this must be even */
 		    if ((asp + vsp + hsp) & 1)
 			hsp--;
-		    if (NRAND(3)) {
-			populateGlider(lp, glider_12S3B3[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else { /* lower probability of big glider */
-			populateGlider(lp, glider_12S3B3[1], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12S456B3) {
-		    /* Must ensure we have only odd cells (x+y+z=odd)
-		       for glider, so this must be even */
-			if ((asp + vsp + hsp) & 1)
-				hsp--;
-			populateGlider(lp, glider_12S456B3[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 14 && lp->patterned_rule == LIFE_14S34B4) {
+		    populateGliders(lp, dim, orth,
+			hsp, vsp, asp, hoff, voff, aoff);
+		} else if (lp->neighbors == 14) {
 		    /* Must ensure we have only z odd cells (z=odd)
 		       for glider, so this must be even */
-			if (asp & 1)
-				asp--;
-			populateGlider(lp, glider_14S34B4[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 14 && lp->patterned_rule == LIFE_14S34B46) {
-		    /* Must ensure we have only z odd cells (z=odd)
-		       for glider, so this must be even */
-			if (asp & 1)
-				asp--;
-			populateGlider(lp, glider_14S34B46[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 18 && lp->patterned_rule == LIFE_18S45B4) {
-		    if (LRAND() & 1) {
-			populateGlider(lp, glider_18S45B4[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else {
-			populateGlider(lp, glider_18S45B4[1], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 20 && lp->patterned_rule == LIFE_20S45B4) {
-		    if (LRAND() & 1) {
-			populateGlider(lp, glider_20S45B4[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else {
-			populateGlider(lp, glider_20S45B4[1], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S23B5) {
-			populateGlider(lp, glider_26S23B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S25B5) {
-			populateGlider(lp, glider_26S25B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S27B5) {
-			populateGlider(lp, glider_26S27B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S35B5) {
-			populateGlider(lp, glider_26S35B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S36B5) {
-			populateGlider(lp, glider_26S36B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S37B5) {
-			populateGlider(lp, glider_26S37B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S38B5) {
-			populateGlider(lp, glider_26S38B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S4B5) {
-			populateGlider(lp, glider_26S4B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S45B5) {
-			populateGlider(lp, glider_26S45B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S47B5) {
-			populateGlider(lp, glider_26S47B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S56B5) {
-			populateGlider(lp, glider_26S56B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S567B6) {
-			populateGlider(lp, glider_26S567B6[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S57B6) {
-			populateGlider(lp, glider_26S57B6[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S58B5) {
-			populateGlider(lp, glider_26S58B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S678B5) {
-			populateGlider(lp, glider_26S678B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S8B5) {
-			populateGlider(lp, glider_26S8B5[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
+		    if (asp & 1)
+			asp--;
+		    populateGliders(lp, dim, orth,
+			hsp, vsp, asp, hoff, voff, aoff);
+		} else if (lp->neighbors == 18 || lp->neighbors == 20 || lp->neighbors == 26) {
+		    populateGliders(lp, dim, orth,
+			hsp, vsp, asp, hoff, voff, aoff);
 		}
-	} else if (r == 1) {
-		if (orthogonal(lp)) {
+	} else if (dim == 1) {
+		if (orth) {
 			hsp = NRAND(V2) + c2 - V2 / 2;
 			vsp = NRAND(V2) + r2 - V2 / 2;
 			asp = (LRAND() & 1) ? s2 - V : s2 + V;
@@ -2740,106 +2840,26 @@ shooter(life3dstruct * lp)
 			voff = -1;
 		if (hsp > c2)
 			hoff = -1;
-		if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12S3B3) {
+		if (lp->neighbors == 12) {
 			/* Must ensure we have only odd cells (x+y+z=odd)
 			   for glider, so this must be even */
-			if ((asp + vsp + hsp) & 1)
-				asp--;
-		    if (NRAND(3)) {
-			populateGlider(lp, glider_12S3B3[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else { /* lower probability of big glider */
-			populateGlider(lp, glider_12S3B3[1], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12S456B3) {
-		    /* Must ensure we have only odd cells (x+y+z=odd)
-		       for glider, so this must be even */
-			if ((asp + vsp + hsp) & 1)
-				asp--;
-			populateGlider(lp, glider_12S456B3[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 14 && lp->patterned_rule == LIFE_14S34B4) {
+		    if ((asp + vsp + hsp) & 1)
+			asp--;
+		    populateGliders(lp, dim, orth,
+			hsp, vsp, asp, hoff, voff, aoff);
+		} else if (lp->neighbors == 14) {
 		    /* Must ensure we have only z odd cells (z=odd)
 		       for glider, so this must be even */
-			if (asp & 1)
-				asp--;
-			populateGlider(lp, glider_14S34B4[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 14 && lp->patterned_rule == LIFE_14S34B46) {
-		    /* Must ensure we have only z odd cells (z=odd)
-		       for glider, so this must be even */
-			if (asp & 1)
-				asp--;
-			populateGlider(lp, glider_14S34B46[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 18 && lp->patterned_rule == LIFE_18S45B4) {
-		    if (LRAND() & 1) {
-			populateGlider(lp, glider_18S45B4[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else {
-			populateGlider(lp, glider_18S45B4[1], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 20 && lp->patterned_rule == LIFE_20S45B4) {
-		    if (LRAND() & 1) {
-			populateGlider(lp, glider_20S45B4[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else {
-			populateGlider(lp, glider_20S45B4[1], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S23B5) {
-			populateGlider(lp, glider_26S23B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S25B5) {
-			populateGlider(lp, glider_26S25B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S27B5) {
-			populateGlider(lp, glider_26S27B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S35B5) {
-			populateGlider(lp, glider_26S35B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S36B5) {
-			populateGlider(lp, glider_26S36B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S37B5) {
-			populateGlider(lp, glider_26S37B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S38B5) {
-			populateGlider(lp, glider_26S38B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S4B5) {
-			populateGlider(lp, glider_26S4B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S45B5) {
-			populateGlider(lp, glider_26S45B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S47B5) {
-			populateGlider(lp, glider_26S47B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S56B5) {
-			populateGlider(lp, glider_26S56B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S567B6) {
-			populateGlider(lp, glider_26S567B6[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S57B6) {
-			populateGlider(lp, glider_26S57B6[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S58B5) {
-			populateGlider(lp, glider_26S58B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S678B5) {
-			populateGlider(lp, glider_26S678B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S8B5) {
-			populateGlider(lp, glider_26S8B5[0], 1,
-				hsp, vsp, asp, hoff, voff, aoff);
+		    if (asp & 1)
+			asp--;
+		    populateGliders(lp, dim, orth,
+			hsp, vsp, asp, hoff, voff, aoff);
+		} else if (lp->neighbors == 18 || lp->neighbors == 20 || lp->neighbors == 26) {
+		    populateGliders(lp, dim, orth,
+			hsp, vsp, asp, hoff, voff, aoff);
 		}
 	} else {
-		if (orthogonal(lp)) {
+		if (orth) {
 			hsp = NRAND(V2) + c2 - V2 / 2;
 			vsp = (LRAND() & 1) ? r2 - V : r2 + V;
 			asp = NRAND(V2) + s2 - V2 / 2;
@@ -2854,104 +2874,16 @@ shooter(life3dstruct * lp)
 			voff = -1;
 		if (hsp > c2)
 			hoff = -1;
-		if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12S3B3) {
+		if (!boundsCheck12(lp->neighbors, hsp, vsp, asp)) {
 			/* Must ensure we have only odd cells (x+y+z=odd)
 			   for glider, so this must be even */
-			if ((asp + vsp + hsp) & 1)
-				vsp--;
-		    if (NRAND(3)) {
-			populateGlider(lp, glider_12S3B3[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else { /* lower probability of big glider */
-			populateGlider(lp, glider_12S3B3[1], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12S456B3) {
-		    /* Must ensure we have only odd cells (x+y+z=odd)
-		       for glider, so this must be even */
-			if ((asp + vsp + hsp) & 1)
-				vsp--;
-			populateGlider(lp, glider_12S456B3[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 14 && lp->patterned_rule == LIFE_14S34B4) {
-		    /* Must ensure we have only z odd cells (z=odd)
-		       for glider, so this must be even */
-			if (asp & 1)
-				asp--;
-			populateGlider(lp, glider_14S34B4[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 14 && lp->patterned_rule == LIFE_14S34B46) {
-		    /* Must ensure we have only z odd cells (z=odd)
-		       for glider, so this must be even */
-			if (asp & 1)
-				asp--;
-			populateGlider(lp, glider_14S34B46[0], 0,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 18 && lp->patterned_rule == LIFE_18S45B4) {
-		    if (LRAND() & 1) {
-			populateGlider(lp, glider_18S45B4[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else {
-			populateGlider(lp, glider_18S45B4[1], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 20 && lp->patterned_rule == LIFE_20S45B4) {
-		    if (LRAND() & 1) {
-			populateGlider(lp, glider_20S45B4[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    } else {
-			populateGlider(lp, glider_20S45B4[1], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		    }
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S23B5) {
-			populateGlider(lp, glider_26S23B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S25B5) {
-			populateGlider(lp, glider_26S25B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S27B5) {
-			populateGlider(lp, glider_26S27B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S35B5) {
-			populateGlider(lp, glider_26S35B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S36B5) {
-			populateGlider(lp, glider_26S36B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S37B5) {
-			populateGlider(lp, glider_26S37B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S38B5) {
-			populateGlider(lp, glider_26S38B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S4B5) {
-			populateGlider(lp, glider_26S4B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S45B5) {
-			populateGlider(lp, glider_26S45B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S47B5) {
-			populateGlider(lp, glider_26S47B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S56B5) {
-			populateGlider(lp, glider_26S56B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S567B6) {
-			populateGlider(lp, glider_26S567B6[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S57B6) {
-			populateGlider(lp, glider_26S57B6[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S58B5) {
-			populateGlider(lp, glider_26S58B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S678B5) {
-			populateGlider(lp, glider_26S678B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
-		} else if (lp->neighbors == 26 && lp->patterned_rule == LIFE_26S8B5) {
-			populateGlider(lp, glider_26S8B5[0], 2,
-				hsp, vsp, asp, hoff, voff, aoff);
+			vsp--;
+		} else if (!boundsCheck14(lp->neighbors, asp)) {
+			/* Must ensure we have only z odd cells (z=odd)
+			   for glider, so this must be even */
+			asp--;
 		}
+		populateGliders(lp, dim, orth, hsp, vsp, asp, hoff, voff, aoff);
 	}
 	return True;
 }
@@ -3076,13 +3008,14 @@ init_life3d(ModeInfo * mi)
 	} else if (lp->allGliders) {
 		switch (lp->neighbors) {
 		case 12:
-			lp->patterned_rule = NRAND(LIFE_12RULES);
+			lp->patterned_rule = NRAND(LIFE_12GLIDERS);
 			break;
 		case 14:
-			lp->patterned_rule = NRAND(LIFE_14RULES);
+			lp->patterned_rule = NRAND(LIFE_14GLIDERS);
 			break;
 		case 18:
 		case 20:
+			/* only one rule for these so do not randomize */
 			lp->patterned_rule = 0;
 			break;
 		case 26:
